@@ -65,7 +65,7 @@ def translate_file(config, target_file, SOURCE_LANG, DEST_LANG):
     fextension = os.path.splitext(target_file)[1]
 
     payload = {'doc': source, 'from': SOURCE_LANG,
-        'to': DEST_LANG, 'map': json.dumps(map), 'ext':fextension}
+        'to': DEST_LANG, 'map': json.dumps(map, ensure_ascii=False), 'ext':fextension}
     # print(payload)
     req = requests.get(SERVER_URL, params=payload)
     # print(req.url)
@@ -75,7 +75,7 @@ def translate_file(config, target_file, SOURCE_LANG, DEST_LANG):
     # result = json.loads(fake_backend(payload))
 
     translated = result['doc']
-    translation_map = json.dumps(result['map'])
+    translation_map = json.dumps(result['map'], ensure_ascii=False)
 
     # Translations overwrite the translated file
     translated_file_path = target_file
@@ -127,7 +127,7 @@ def translate_all(config, DEST_LANG, additional_ignores=[]):
     else:
         with open(TRANSLATE_TEMP_FILENAME, 'w+') as f:
             tmp_data = {'current_lang':config['source_lang']}
-            f.write(json.dumps(tmp_data))
+            f.write(json.dumps(tmp_data, ensure_ascii=False))
         SOURCE_LANG = config['source_lang']
 
     for file in target_files:
@@ -139,7 +139,7 @@ def translate_all(config, DEST_LANG, additional_ignores=[]):
         tmp_data = json.loads(f.read())
         tmp_data['current_lang'] = DEST_LANG
     with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-        f.write(json.dumps(tmp_data))
+        f.write(json.dumps(tmp_data, ensure_ascii=False))
 
 def main():
     # Load project config file
@@ -167,7 +167,7 @@ def main():
     if not os.path.isfile(TRANSLATE_TEMP_FILENAME):
         with open(TRANSLATE_TEMP_FILENAME, 'w+') as f:
             tmp_data = {'current_lang':config['source_lang']}
-            f.write(json.dumps(tmp_data))
+            f.write(json.dumps(tmp_data, ensure_ascii=False))
 
     parser = argparse.ArgumentParser()
     parser.add_argument('command', choices=['translate', 'untranslate',
@@ -187,8 +187,8 @@ def main():
         # If a specific output language is specified, use it
         if args.language:
             OUTPUT_LANG = args.language
-        translate_file(config, args.single_file, config['source_lang'],
-            OUTPUT_LANG)
+            translate_file(config, args.single_file, config['source_lang'],
+                OUTPUT_LANG)
 
         # If a single file is specified, apply translation to that file
         if args.single_file:
@@ -204,7 +204,7 @@ def main():
                     tmp_data['single_translated_files'] = [
                         '{} {}'.format(args.single_file, OUTPUT_LANG)]
             with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                f.write(json.dumps(tmp_data))
+                f.write(json.dumps(tmp_data, ensure_ascii=False))
         else:
             translate_all(config, OUTPUT_LANG)
 
@@ -261,7 +261,7 @@ def main():
                             tmp_data['single_translated_files'] = st_files
 
                     with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                        f.write(json.dumps(tmp_data))
+                        f.write(json.dumps(tmp_data, ensure_ascii=False))
 
                 else:
                     # Untranslate that specific file and mark it in the
@@ -272,7 +272,7 @@ def main():
                         args.single_file, config['source_lang']))
                     tmp_data['single_translated_files'] = st_files
                     with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                        f.write(json.dumps(tmp_data))
+                        f.write(json.dumps(tmp_data, ensure_ascii=False))
 
             else:
                 # Untranslate every file that is not found in the
@@ -296,7 +296,7 @@ def main():
                 # Change the repo language back to the source
                 tmp_data['current_lang'] = config['source_lang']
                 with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                    f.write(json.dumps(tmp_data))
+                    f.write(json.dumps(tmp_data, ensure_ascii=False))
         else:
             # The whole repo has not yet been translated.
 
@@ -322,7 +322,7 @@ def main():
                             tmp_data['single_translated_files'] = st_files
 
                     with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                        f.write(json.dumps(tmp_data))
+                        f.write(json.dumps(tmp_data, ensure_ascii=False))
                 else:
                     print('Error: Target file has not yet been translated')
                     sys.exit()
@@ -339,7 +339,7 @@ def main():
                 # Clear the list of specially translated files
                 tmp_data['single_translated_files'] = []
                 with open(TRANSLATE_TEMP_FILENAME, 'w') as f:
-                    f.write(json.dumps(tmp_data))
+                    f.write(json.dumps(tmp_data, ensure_ascii=False))
 
     if args.command == 'commit':
         pass
@@ -427,7 +427,7 @@ def main():
         fextension = os.path.splitext(target_file)[1]
 
         payload = {'doc': source, 'from': SOURCE_LANG,
-            'to': DEST_LANG, 'map': json.dumps(map), 'ext':fextension}
+            'to': DEST_LANG, 'map': json.dumps(map, ensure_ascii=False), 'ext':fextension}
         # print(payload)
         req = requests.get(SERVER_URL, params=payload)
         # print(req.url)
@@ -456,7 +456,7 @@ def main():
         fextension = os.path.splitext(target_file)[1]
 
         payload = {'doc': source, 'from': SOURCE_LANG,
-            'to': DEST_LANG, 'map': json.dumps(map), 'ext':fextension}
+            'to': DEST_LANG, 'map': json.dumps(map, ensure_ascii=False), 'ext':fextension}
         # print(payload)
         req = requests.get(SERVER_URL, params=payload)
         # print(req.url)
@@ -488,7 +488,7 @@ def main():
         fextension = os.path.splitext(target_file)[1]
 
         payload = {'doc': source, 'from': SOURCE_LANG,
-            'to': DEST_LANG, 'map': json.dumps(map), 'ext':fextension}
+            'to': DEST_LANG, 'map': json.dumps(map, ensure_ascii=False), 'ext':fextension}
         # print(payload)
         req = requests.get(SERVER_URL, params=payload)
         # print(req.url)
